from json import dumps
import logging
from urllib.parse import urljoin

from aioze.access import Access

_LOGGER = logging.getLogger(__package__)


class Grade:
    def __init__(self, access: Access):
        self._access = access

    async def get_grades(self, pupil):
        """Get grade averages for a given student"""
        if not await self._access.is_authenticated():
            await self._access.authenticate()
        # https://api-enc.hauts-de-seine.fr/v1/viescolaire/EHNotesFamille?aEleveIds=6123d148a14ce70e0ca6f797&ctx_etab=0920077J&ctx_profil=RESPONSABLE_ELEVE
        params = {
            "ctx_profil": self._access.profil,
            "ctx_etab": self._access.etab,
            "aEleveIds": pupil['uid']
        }
        grades_url = urljoin(self._access.api_url, "/v1/viescolaire/EHNotesFamille")
        _LOGGER.debug("Getting '%s' with params '%s'", grades_url, dumps(params))
        res = await self._access.api_wrapper("get", grades_url, params=params)
        if res.status != 200:
            _LOGGER.error("Error fetching grades: '%s'", res.reason)
            return
        return await res.json()



import json
import logging
from urllib.parse import urljoin

from aioze.access import Access

_LOGGER = logging.getLogger(__package__)


class Email:
    def __init__(self, access: Access):
        self._access = access

    async def get_emails(self):
        """Get events for a given calendar (uid = student id)"""
        if not await self._access.is_authenticated():
            await self._access.authenticate()
        params = {
            "pFolderId": "/inbox",
            "pIncludeRead": "true",
            "pIncludeUnread": "true",
            "pIncludeWithAttach": "true",
            "pIncludeWithout": "true",
            "pSortPattern": "dt_inv",
            "pPageSize": "15",
            "ctx_profil": self._access.profil,
            "ctx_etab": self._access.etab,
        }
        cours_url = urljoin(self._access.api_url, "/v1/email/messages")
        _LOGGER.debug("Getting '%s' with params '%s'", cours_url, json.dumps(params))
        res = await self._access.api_wrapper("get", cours_url, params=params)
        if res.status != 200:
            _LOGGER.error("Error fetching Oze emails: '%s'", res.reason)
            return
        return await res.json()



import logging
from urllib.parse import urljoin

from aioze.access import Access

_LOGGER = logging.getLogger(__package__)


class Information:
    def __init__(self, access: Access):
        self._access = access

    async def get_informations(self, pupil = None):
        # pylint: disable=unused-argument
        """Get information notices"""
        if not await self._access.is_authenticated():
            await self._access.authenticate()
        info_url = urljoin(self._access.api_url, "/v1/information/lecteur")
        params = {
            "start": 0,
            "limit": 10,
            "activeState": 0,
            "periodTypeSelected": "CURRENTYEAR",
            "allInformations": "false",
            "ctx_etab": self._access.etab,
            "ctx_profil": self._access.profil,
        }
        res = await self._access.api_wrapper("get", info_url, params=params)
        if res.status != 200:
            _LOGGER.error(
                "Error fetching Oze information notices: '%s'", res.reason
            )
            return
        return await res.json()



# -*- coding:utf-8 -*-

__all__ = []

from aioze.api.event import Event
from aioze.api.punishment import Punishment
from aioze.api.notification import Notification
from aioze.api.information import Information
from aioze.api.homework import Homework
from aioze.api.userinfo import UserInfo
from aioze.api.email import Email
from aioze.api.grade import Grade



import json
import logging
from datetime import datetime, timedelta
from urllib.parse import urljoin

from aioze.access import Access

_LOGGER = logging.getLogger(__package__)


class Event:
    def __init__(self, access: Access):
        self._access = access

    async def get_events(
        self,
        pupil,
        start_date: datetime,
        end_date: datetime = None,
        days: int = 1,
    ):
        """Get events for a given calendar (uid = student id)"""
        if not await self._access.is_authenticated():
            await self._access.authenticate()
        # start = start_date or dt.start_of_local_day()
        end = end_date or (start_date + timedelta(days=days))
        params = {
            "ctx_profil": self._access.profil,
            "ctx_etab": self._access.etab,
            "aDateDebut": start_date.astimezone().replace(microsecond=0).isoformat()[:-6]
            + "Z",
            "aDateFin": end.astimezone().replace(microsecond=0).isoformat()[:-6] + "Z",
            "aPupilles": pupil['uid'],
            "aWithCurrent": "false",
            "aUais": self._access.etab,
        }
        cours_url = urljoin(self._access.api_url, "/v1/cours/me")
        _LOGGER.debug("Getting '%s' with params '%s'", cours_url, json.dumps(params))
        res = await self._access.api_wrapper("get", cours_url, params=params)
        if res.status != 200:
            _LOGGER.error("Error fetching Oze events for '%s': '%s'", pupil['name'], res.reason)
            return
        return await res.json()



import logging
from datetime import datetime
from dateutil import tz
from urllib.parse import urljoin

from aioze.access import Access

_LOGGER = logging.getLogger(__package__)


class Homework:
    def __init__(self, access: Access):
        self._access = access

    async def get_homework(self, pupil):
        """Get howework"""
        if not await self._access.is_authenticated():
            await self._access.authenticate()
        annee_url = urljoin(self._access.api_url, "/v1/etabs/zone/annee")
        params = {
            "aNotNull": "true",
            "ctx_etab": self._access.etab,
            "ctx_profil": self._access.profil,
        }
        res = await self._access.api_wrapper("get", annee_url, params=params)
        if res.status != 200:
            _LOGGER.error(
                "Error fetching Oze year data: '%s'", res.reason
            )
            return
        annee_data = await res.json()
        _LOGGER.debug("Année: %s", annee_data)
        homework_url = urljoin(self._access.api_url, "/v1/travaux/liste")
        start = datetime.combine(datetime.utcnow().date(), datetime.min.time())
        params = {
            "aDateDebut": start.astimezone(tz.UTC).isoformat()[:-9],
            "aDateFin": annee_data['fin'][:-4],
            "aIdsUsers": pupil['uid'],
            "ctx_etab": self._access.etab,
            "ctx_profil": self._access.profil,
        }
        res = await self._access.api_wrapper("get", homework_url, params=params)
        if res.status != 200:
            _LOGGER.error(
                "Error fetching Oze information notices: '%s'", res.reason
            )
            return
        return await res.json()
